from django import forms

from django.contrib.auth import get_user_model
from django.utils.timezone import now
from django.utils.translation import ugettext_lazy as _

from . import models

class UpdateProfileForm(forms.ModelForm):
    first_name = forms.CharField(
        label=_('first name').title(),
        max_length=64)
    last_name = forms.CharField(
        label=_('last name').title(),
        max_length=64)
    email = forms.EmailField(
        label=_('email address').title(),
        max_length=254)

    def __init__(self, *args, **kwargs):
        self.request = kwargs.pop('request')
        super(UpdateProfileForm, self).__init__(*args, **kwargs)

    def save(self, commit=True):
        self.instance.updated = now()
        self.instance.send_mail(self.request)
        return super(UpdateProfileForm, self).save(commit=commit)

    class Meta:
        model = models.ProfileUpdate
        fields = [
            'first_name',
            'last_name',
            'email',
        ]
